Crate libnewsboat

Crate libnewsboat 

Modules

charencoding
cliargsparser
configpaths
filterparser
Parses filter expressions.
fmtstrformatter
Produces strings of values in a specified format, strftime(3)-like.
fslock
history
human_panic
Provides a panic hook with a user-friendly message.
keycombination
keymap
links
logger
Keeps a record of what the program did.
matchable
matcher
Checks if given filter expression is true for a given feed or article.
matchererror
scopemeasure
Measures time spent in a given scope, and writes it to the log.
stflrichtext
utils

Macros

log
Convenience macro for logging.